aboutsummaryrefslogtreecommitdiffstats
path: root/dex
diff options
context:
space:
mode:
authorWei-Ning Huang <w@cobinhood.com>2018-10-09 12:29:49 +0800
committerWei-Ning Huang <w@dexon.org>2018-12-19 20:54:27 +0800
commitf54b89781ed7337653e4cc0ab5c591aea91390de (patch)
treebb9fe048277544311025c055ff706b63719ae82b /dex
parent268bc7489ad87a4f55200af66f82a3985fc096e0 (diff)
downloaddexon-f54b89781ed7337653e4cc0ab5c591aea91390de.tar
dexon-f54b89781ed7337653e4cc0ab5c591aea91390de.tar.gz
dexon-f54b89781ed7337653e4cc0ab5c591aea91390de.tar.bz2
dexon-f54b89781ed7337653e4cc0ab5c591aea91390de.tar.lz
dexon-f54b89781ed7337653e4cc0ab5c591aea91390de.tar.xz
dexon-f54b89781ed7337653e4cc0ab5c591aea91390de.tar.zst
dexon-f54b89781ed7337653e4cc0ab5c591aea91390de.zip
core: vm: refactor and add DKGFinalizeds related implementations
Diffstat (limited to 'dex')
-rw-r--r--dex/governance.go13
-rw-r--r--dex/network.go4
2 files changed, 13 insertions, 4 deletions
diff --git a/dex/governance.go b/dex/governance.go
index 5ee307b88..e990f32f3 100644
--- a/dex/governance.go
+++ b/dex/governance.go
@@ -35,7 +35,7 @@ func (d *DexconGovernance) NodeSet(round uint64) []crypto.PublicKey {
}
// AddDKGComplaint adds a DKGComplaint.
-func (d *DexconGovernance) AddDKGComplaint(complaint *types.DKGComplaint) {
+func (d *DexconGovernance) AddDKGComplaint(round uint64, complaint *types.DKGComplaint) {
}
// DKGComplaints gets all the DKGComplaints of round.
@@ -44,10 +44,19 @@ func (d *DexconGovernance) DKGComplaints(round uint64) []*types.DKGComplaint {
}
// AddDKGMasterPublicKey adds a DKGMasterPublicKey.
-func (d *DexconGovernance) AddDKGMasterPublicKey(masterPublicKey *types.DKGMasterPublicKey) {
+func (d *DexconGovernance) AddDKGMasterPublicKey(round uint64, masterPublicKey *types.DKGMasterPublicKey) {
}
// DKGMasterPublicKeys gets all the DKGMasterPublicKey of round.
func (d *DexconGovernance) DKGMasterPublicKeys(round uint64) []*types.DKGMasterPublicKey {
return nil
}
+
+// AddDKGFinalize adds a DKG finalize message.
+func (d *DexconGovernance) AddDKGFinalize(round uint64, final *types.DKGFinalize) {
+}
+
+// IsDKGFinal checks if DKG is final.
+func (d *DexconGovernance) IsDKGFinal(round uint64) bool {
+ return false
+}
diff --git a/dex/network.go b/dex/network.go
index b19b46147..24ef2cc63 100644
--- a/dex/network.go
+++ b/dex/network.go
@@ -39,8 +39,8 @@ func (n *DexconNetwork) BroadcastDKGPartialSignature(
psig *types.DKGPartialSignature) {
}
-// BroadcastRandomnessRequest broadcasts rand request to DKG set.
-func (n *DexconNetwork) BroadcastRandomnessRequest(randRequest *types.AgreementResult) {
+// BroadcastAgreementResult broadcasts rand request to DKG set.
+func (n *DexconNetwork) BroadcastAgreementResult(randRequest *types.AgreementResult) {
}